@@ -1,3 +1,4 @@
+
 add_data_from_standard_block <- function(data, block){
   ## increment node id
   id <- get_last_id(data) + 1
@@ -13,8 +14,7 @@ add_data_from_standard_block <- function(data, block){
       code_str = "")
   } else {
     ## build string to be displayed from block code
-    code_str <- sapply(as.list(block), function(x)
-      paste(deparse(x, width.cutoff = 40L, backtick = TRUE), collapse = "\n"))
+    code_str <- sapply(as.list(block), robust_deparse)
     code_str <- styler::style_text(code_str)
     code_str <- paste(code_str, collapse = "\n")
     ## add current node
