@@ -4,7 +4,9 @@ test_that("flow_data works with an empty for loop",{
   fun <- function(x) {
     for(x in foo) {}
   }
-  expect_snapshot(flow_data(fun))
+  out <- flow_data(fun)
+  out$nodes$code_str <- gsub("\u2800", " ", out$nodes$code_str)
+  expect_snapshot(out)
 })
 
 # simple for loop
@@ -12,7 +14,9 @@ test_that("flow_data works with simple for loop",{
   fun <- function(x) {
     for(x in foo) x
   }
-  expect_snapshot(flow_data(fun))
+  out <- flow_data(fun)
+  out$nodes$code_str <- gsub("\u2800", " ", out$nodes$code_str)
+  expect_snapshot(out)
 })
 
 
@@ -21,7 +25,9 @@ test_that("flow_data works with simple while loop",{
   fun <- function(x) {
     while(foo) x
   }
-  expect_snapshot(flow_data(fun))
+  out <- flow_data(fun)
+  out$nodes$code_str <- gsub("\u2800", " ", out$nodes$code_str)
+  expect_snapshot(out)
 })
 
 # simple repeat loop
@@ -29,7 +35,9 @@ test_that("flow_data works with simple repeat loop",{
   fun <- function(x) {
     repeat x
   }
-  expect_snapshot(flow_data(fun))
+  out <- flow_data(fun)
+  out$nodes$code_str <- gsub("\u2800", " ", out$nodes$code_str)
+  expect_snapshot(out)
 })
 
 # if else call with for loops on each side
@@ -40,5 +48,7 @@ test_that("flow_data works if else call with for loops on each side",{
     else
       for(x in qux) quux
   }
-  expect_snapshot(flow_data(fun))
+  out <- flow_data(fun)
+  out$nodes$code_str <- gsub("\u2800", " ", out$nodes$code_str)
+  expect_snapshot(out)
 })
